==> jboss-as-messaging-7.0.1.Final-sources.jar: org/jboss/as/messaging/RemotingInterceptorsAttribute.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.messaging;

import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamWriter;

import java.util.List;

import org.jboss.as.controller.ListAttributeDefinition;
import org.jboss.as.controller.descriptions.ModelDescriptionConstants;
import org.jboss.as.controller.operations.validation.StringLengthValidator;
import org.jboss.dmr.ModelNode;
import org.jboss.dmr.ModelType;

/**
 * {@link org.jboss.as.controller.AttributeDefinition} for the HQ server resource's remoting-interceptors attribute.
 *
 * @author Brian Stansberry (c) 2011 Red Hat Inc.
 */
public class RemotingInterceptorsAttribute extends ListAttributeDefinition {

    public static final RemotingInterceptorsAttribute INSTANCE = new RemotingInterceptorsAttribute();

    private RemotingInterceptorsAttribute() {
        super(CommonAttributes.REMOTING_INTERCEPTORS_STRING, CommonAttributes.REMOTING_INTERCEPTORS_STRING, true, 1, Integer.MAX_VALUE, new StringLengthValidator(1));
    }

    @Override
    public void marshallAsElement(ModelNode resourceModel, XMLStreamWriter writer) throws XMLStreamException {
        if (resourceModel.hasDefined(getName())) {
            List<ModelNode> list = resourceModel.get(getName()).asList();
            if (list.size() > 0) {
                writer.writeStartElement(getXmlName());

                for (ModelNode child : list) {
                    writer.writeStartElement(Element.CLASS_NAME.getLocalName());
                    writer.writeCharacters(child.asString());
                    writer.writeEndElement();
                }

                writer.writeEndElement();
            }
        }
    }

    @Override
    protected void addValueTypeDescription(ModelNode node) {
        node.get(ModelDescriptionConstants.VALUE_TYPE).set(ModelType.STRING);
    }
}

==> jboss-as-messaging-7.1.2.Final-sources.jar: org/jboss/as/messaging/RemotingInterceptorsAttribute.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.messaging;

import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamWriter;

import java.util.List;
import java.util.Locale;
import java.util.ResourceBundle;

import org.jboss.as.controller.ListAttributeDefinition;
import org.jboss.as.controller.descriptions.ModelDescriptionConstants;
import org.jboss.as.controller.descriptions.ResourceDescriptionResolver;
import org.jboss.as.controller.operations.validation.StringLengthValidator;
import org.jboss.as.controller.registry.AttributeAccess;
import org.jboss.dmr.ModelNode;
import org.jboss.dmr.ModelType;

/**
 * {@link org.jboss.as.controller.AttributeDefinition} for the HQ server resource's remoting-interceptors attribute.
 *
 * @author Brian Stansberry (c) 2011 Red Hat Inc.
 */
public class RemotingInterceptorsAttribute extends ListAttributeDefinition {

    public static final RemotingInterceptorsAttribute INSTANCE = new RemotingInterceptorsAttribute();

    private RemotingInterceptorsAttribute() {
        super(CommonAttributes.REMOTING_INTERCEPTORS_STRING, CommonAttributes.REMOTING_INTERCEPTORS_STRING, true, 1,
                Integer.MAX_VALUE, new StringLengthValidator(1), null, null, AttributeAccess.Flag.RESTART_ALL_SERVICES);
    }

    @Override
    public void marshallAsElement(ModelNode resourceModel, XMLStreamWriter writer) throws XMLStreamException {
        if (resourceModel.hasDefined(getName())) {
            List<ModelNode> list = resourceModel.get(getName()).asList();
            if (list.size() > 0) {
                writer.writeStartElement(getXmlName());

                for (ModelNode child : list) {
                    writer.writeStartElement(Element.CLASS_NAME.getLocalName());
                    writer.writeCharacters(child.asString());
                    writer.writeEndElement();
                }

                writer.writeEndElement();
            }
        }
    }

    @Override
    protected void addValueTypeDescription(ModelNode node, ResourceBundle bundle) {
        setValueType(node);
    }

    @Override
    protected void addAttributeValueTypeDescription(ModelNode node, ResourceDescriptionResolver resolver, Locale locale, ResourceBundle bundle) {
        setValueType(node);
    }

    @Override
    protected void addOperationParameterValueTypeDescription(ModelNode node, String operationName, ResourceDescriptionResolver resolver, Locale locale, ResourceBundle bundle) {
        setValueType(node);
    }

    private void setValueType(ModelNode node) {
        node.get(ModelDescriptionConstants.VALUE_TYPE).set(ModelType.STRING);
    }
}
